OC.L10N.register(
    "core",
    {
    "Please select a file." : "Seleccionatz un fichièr.",
    "File is too big" : "Fichièr tròp pesuc",
    "The selected file is not an image." : "Lo fichièr seleccionat es pas un imatge.",
    "The selected file cannot be read." : "Se pòt pas legir lo fichièr seleccionat.",
    "The file was uploaded" : "Lo fichièr es estat enviat",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Lo fichièr enviat despassa la directiva upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Lo fichièr enviat despassa la directiva MAX_FILE_SIZE especificada dins lo formulari HTML",
    "The file was only partially uploaded" : "Lo fichièr es estat parcialament enviat",
    "No file was uploaded" : "Cap de fichièr pas enviat",
    "Missing a temporary folder" : "Dossièr temporari absent",
    "Could not write file to disk" : "Escritura impossibla al disc",
    "A PHP extension stopped the file upload" : "Una extension PHP a arrestat lo mandadís de fichièr",
    "Invalid file provided" : "Fichièr fornit invalid",
    "No image or file provided" : "Cap d’imatge o fichièr fornit",
    "Unknown filetype" : "Tipe de fichièr desconegut",
    "An error occurred. Please contact your admin." : "Una error s’es producha. Volgatz ben contactar l’admin.",
    "Invalid image" : "Imatge desconegut",
    "No temporary profile picture available, try again" : "Cap d’imatge de perfil temporari pas disponible, tornatz ensajar",
    "No crop data provided" : "Cap de donada de produccion",
    "No valid crop data provided" : "Cap de donada pas valida pas provesida",
    "Crop is not square" : "Lo retalhatge es pas carrat",
    "State token does not match" : "Lo geton d’estat correspond pas",
    "Invalid app password" : "Senhal d’aplicacion invalid",
    "Could not complete login" : "Autocomplecion impossibla de l’identificant",
    "Your login token is invalid or has expired" : "Lo geton es siá invalid siá expirat",
    "Login" : "Login",
    "Password reset is disabled" : "Reïnicializacion del senhal desactivada",
    "Could not reset password because the token is expired" : "Reïnicializacion del senhal impossibla pr’amor que lo geton a expirat",
    "Could not reset password because the token is invalid" : "Reïnicializacion del senhal impossibla pr’amor que lo geton es invalid",
    "%s password reset" : "reïnicializar lo senhal de %s",
    "Password reset" : "Reïnicializacion de senhal",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Clicat sul boton seguent per reïnicializar vòstre senhal. S’avètz pas demandat sa reïnicializacion, ignoratz aqueste corrièl.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Clicat sul ligam seguent per reïnicializar vòstre senhal. S’avètz pas demandat sa reïnicializacion, ignoratz aqueste corrièl.",
    "Reset your password" : "Reïnicializatz vòstre senhal",
    "Nextcloud Server" : "Servidor Nextcloud",
    "Some of your link shares have been removed" : "D’unes de vòstres ligams de partiment foguèron tirats",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "A causa d’una avaria de seguretat nos calguèt tirar certans de vòstres ligams de partiment. Vejatz lo ligam per mai d’informacions.",
    "Learn more ↗" : "Ne saber mai ↗",
    "Preparing update" : "Preparacion de la mesa a jorn",
    "[%d / %d]: %s" : "[%d / %d] : %s",
    "Repair step:" : "Etapa de reparacion :",
    "Repair info:" : "Info de reparacion :",
    "Repair warning:" : "Avertiment de reparacion :",
    "Repair error:" : "Error de reparacion :",
    "Turned on maintenance mode" : "Mòde manteniment aviat",
    "Turned off maintenance mode" : "Mòde manteniment atudat",
    "Maintenance mode is kept active" : "Lo mòde manteniment ten d’èsser actiu",
    "Updating database schema" : "Actualizacion de l’esquèma de la basa de donadas",
    "Updated database" : "Basa de donada mesa a jorn",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificacion se l’esquèma de la basa de donadas per %s pòt èsser actualizat (aquò pòt trigar segon la talha de basa de donadas)",
    "Updated \"%1$s\" to %2$s" : "« %1$s » mes a jorn a %2$s",
    "Set log level to debug" : "Definir lo nivèl de jornal d’audit al nivèl debugatge",
    "Reset log level" : "Restablir nivèl de jornals",
    "Starting code integrity check" : "Debuta de la verificacion d’integritat del còdi",
    "Finished code integrity check" : "Cerificacion d’integritat del còdi acabada",
    "%s (incompatible)" : "%s (incompatible)",
    "The following apps have been disabled: %s" : "Las aplicacions seguentas son estadas desactivadas : %s",
    "Already up to date" : "Ja a jorn",
    "Error occurred while checking server setup" : "Error producha pendent la verificacion de l’installacion del servidor",
    "unknown text" : "tèxt desconegut",
    "Hello world!" : "Adieu monde !",
    "sunny" : "ensolelhat",
    "Hello {name}, the weather is {weather}" : "Adiu {name}, lo temps es {weather}",
    "Hello {name}" : "Adiu {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Vaquí vòstres resultats de recèrca<script>alert(1)</script></strong>",
    "new" : "nòu",
    "_download %n file_::_download %n files_" : ["telecargar %n fichièr","telecargar %n fichièrs"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "La mesa a jorn es en cors, quitar aquesta pagina poiriá interrompre lo processús dins d’unes environaments.",
    "Update to {version}" : "Metre a jorn a {version}",
    "An error occurred." : "Una error s’es producha.",
    "Please reload the page." : "Volgatz recargar la pagina.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La mesa a jorn a pas reüssit. Mai mai d’informacions <a href=\"{url}\">visitatz nòstra publicacion al forum</a> que tracta d’aqueste problèma.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La mesa a jorn a pas reüssit. Mercés de senhalar aqueste problèma a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunautat Nexcloud</a>.",
    "Continue to {productName}" : "Contunhar cap a {productName}",
    "Apps" : "Aplicacions",
    "More apps" : "Mai d’aplicacions",
    "_{count} notification_::_{count} notifications_" : ["{count} notificacion","{count} notificacions"],
    "No" : "No",
    "Yes" : "Yes",
    "Searching …" : "Recèrca…",
    "Start typing to search" : "Començatz de picar per recercar",
    "Today" : "Uèi",
    "Date" : "Data",
    "People" : "Gent",
    "Load more results" : "Cargar mai de resultats",
    "Log in" : "Connexion",
    "Logging in …" : "Identificacion…",
    "Log in to {productName}" : "Se connectar a {productName}",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Avèm detectat mantun ensag invalid de connexion a partir de vòstra IP. Per consequent vòstra connexion venenta serà en pausa per 30 segondas.",
    "Account name or email" : "Nom d’utilizaire o email",
    "Server side authentication failed!" : "Autentificacion costat servidor fracassada !",
    "Please contact your administrator." : "Mercés de contactar vòstre administrator.",
    "An internal error occurred." : "Una error intèrna s’es producha.",
    "Please try again or contact your administrator." : "Tornatz ensajar o contactatz vòstre administrator.",
    "Password" : "Senhal",
    "Log in with a device" : "Connexion amb un periferic",
    "Your account is not setup for passwordless login." : "Vòstre compte es pas parametrat per una autentificacion sens senhal.",
    "Your connection is not secure" : "Vòstra connexion es pas segura",
    "Passwordless authentication is only available over a secure connection." : "L’autentificacion sens senhal es sonque disponibla via una connexion segura.",
    "Browser not supported" : "Navegador pas pres en carga",
    "Passwordless authentication is not supported in your browser." : "L’autentificacion sens senhal es pas presa en cargar per vòstre navegador.",
    "Reset password" : "Reïnicializar senhal",
    "Back to login" : "Tornar a la connexion",
    "Couldn't send reset email. Please contact your administrator." : "Impossible de mandar lo corrièl de reïnicializacion. Contactatz vòstre administrator.",
    "Password cannot be changed. Please contact your administrator." : "Se pòt pas cambiar lo senhal. Mercés de contactar vòstre administrator.",
    "New password" : "Senhal novèl",
    "I know what I'm doing" : "Sabi çò que fau",
    "Resetting password" : "Reïnicializacion de senhal",
    "Schedule work & meetings, synced with all your devices." : "Planificatz prètzfaches e reünions, sincronizats amb totes vòstres periferics.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Gardatz vòstres companhs e amics a un sòl lòc sens divulgar lor vida privada.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicacion simpla e simpatica de corrièl integrada a Fichièrs, Contactes e Calendièr.",
    "Recommended apps" : "Aplicacions recomandadas",
    "Loading apps …" : "Cargament aplicacions…",
    "App download or installation failed" : "Telecargament o installacion de l’aplicacion fracassada",
    "Cannot install this app because it is not compatible" : "Impossibla d’installar aquesta app perque es pas compatibla",
    "Cannot install this app" : "Impossible d’installar aquesta app",
    "Skip" : "Sautar",
    "Installing apps …" : "Installacion aplicacions…",
    "Install recommended apps" : "Installar las aplicacions recomandadas",
    "Settings menu" : "Menú paramètres",
    "Loading your contacts …" : "Cargaments dels contactes…",
    "Looking for {term} …" : "Recèrca de {term}…",
    "Search contacts" : "Cercar pels contactes",
    "Reset search" : "Escafar la recèrca",
    "Search contacts …" : "Cercar pels contactes…",
    "Could not load your contacts" : "Cargament impossible de vòstres contactes",
    "No contacts found" : "Cap de contact pas trobat",
    "Install the Contacts app" : "Installar l’aplicacion Contactes",
    "Search" : "Recercar",
    "No results for {query}" : "Cap de resultat per {query}",
    "An error occurred while searching for {type}" : "Una error s’es producha en cercant {type}",
    "Search for {name} only" : "Cercar sonque {name}",
    "Loading more results …" : "Cargament de mai de resultats…",
    "Forgot password?" : "Senhal oblidat ?",
    "Back" : "Retorn",
    "Login form is disabled." : "Lo formulari de connexion es desactivat.",
    "More actions" : "Mai d’accions",
    "Security warning" : "Avertiment de seguretat",
    "Storage & database" : "Emmagazinatge & basa de donada",
    "Data folder" : "Dossièr de donadas",
    "Install and activate additional PHP modules to choose other database types." : "Installatz e activatz los modules PHP complementaris per causir d’autres tipes de basas de donadas.",
    "For more details check out the documentation." : "Per mai de detalhs consultatz la documentacion.",
    "Performance warning" : "Avertiment de performança",
    "You chose SQLite as database." : "Causissètz SQLite coma basa de donadas.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite deu solament èsser utilizat per d’instàncias minimalas e de desvolopament. Per la produccion recomandam un autre sistèma de basa de donadas.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "S’utilizatz los clients per sincronizar de fichièrs, l’utilizacion de SQLite es forçadament descoratjada.",
    "Database user" : "Utilizaire basa de donadas",
    "Database password" : "Senhal basa de donadas",
    "Database name" : "Nom basa de donadas",
    "Database tablespace" : "Tablespace basa de donadas",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Volgatz especificar lo numèro de pòrt aprèp lo nom d’òste (ex : localhost:5432).",
    "Database host" : "Òste basa de donadas",
    "Installing …" : "Installacion...",
    "Install" : "Installar",
    "Need help?" : "Besonh d’ajuda ?",
    "See the documentation" : "Vejatz la documentacion",
    "{name} version {version} and above" : "{name} version {version} e ulterior",
    "This browser is not supported" : "Aqueste navigador es pas pres en carga",
    "Supported versions" : "Versions presas en carga",
    "Search {types} …" : "Recèrca {types}…",
    "Choose" : "Causir",
    "Copy" : "Copiar",
    "Move" : "Move",
    "OK" : "D'acòrdi",
    "read-only" : "lectura-sola",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicte de fichièr","{count} conflictes de fichièr"],
    "One file conflict" : "Un conflicte de fichièr",
    "New Files" : "Fichièrs novèls",
    "Already existing files" : "Fichièrs ja existents",
    "Which files do you want to keep?" : "Quines fichièrs volètz gardar ?",
    "If you select both versions, the copied file will have a number added to its name." : "Se seleccionatz las doas versions, lo fichièr copiat aurà un nombre apondut al seu nom.",
    "Cancel" : "Anullar",
    "Continue" : "Contunhar",
    "(all selected)" : "(totes seleccionats)",
    "({count} selected)" : "({count} seleccionats)",
    "Saving …" : "Enregistrament…",
    "seconds ago" : "fa qualques segondas",
    "Connection to server lost" : "Connexion al servidor perduda",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problèma de cargar de la pagina, actualizacion d’aquí %n seconda","Problèma de cargar de la pagina, actualizacion d’aquí %n secondas"],
    "Add to a project" : "Ajustar a un projècte",
    "Show details" : "Mostrar detalhs",
    "Hide details" : "Amagar detalhs",
    "Rename project" : "Renomenar lo projècte",
    "Failed to rename the project" : "Renomenatge impossible del projècte",
    "Failed to create a project" : "Creacion d’un projècte fracassada",
    "Failed to add the item to the project" : "Apondon fracassat d’un element al projècte",
    "Connect items to a project to make them easier to find" : "Connectatz d’elements a un projècte per lo rendre mai simples de trobar",
    "New in" : "Nòu dins",
    "View changelog" : "Veire jornal de modificacions",
    "No action available" : "Cap d’accion pas disponibla",
    "Error fetching contact actions" : "Error en recuperacion las accions contacte",
    "Non-existing tag #{tag}" : "Etiqueta inexistenta #{tag}",
    "Restricted" : "Restrencha",
    "Invisible" : "Invisible",
    "Delete" : "Suprimir",
    "Rename" : "Renomenar",
    "Collaborative tags" : "Etiquetas collaborativas",
    "No tags found" : "Cap d’etiqueta pas trobada",
    "Personal" : "Personal",
    "Admin" : "Admin",
    "Help" : "Ajuda",
    "Access forbidden" : "Accès defendut",
    "Page not found" : "Pagina pas trobada",
    "Back to %s" : "Tornar a %s",
    "Too many requests" : "Tròp de requèstas",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "I a agut tròp de requèstas a partir de vòstre ret. Tornatz ensajar mai tard o contactatz vòstre administrator s’aquò es una error.",
    "Error" : "Error",
    "Internal Server Error" : "Error intèrna del servidor",
    "The server was unable to complete your request." : "Lo servidor a pas pogut terminar vòstra requèsta.",
    "If this happens again, please send the technical details below to the server administrator." : "S’aquò tòrna arribar, enviatz lo detalhs tecnics çai-jos a l’administrator del servidor.",
    "More details can be found in the server log." : "Mai de detalhs se tròban als jornals d’audit del servidor.",
    "Technical details" : "Detalhs tecnics",
    "Remote Address: %s" : "Adreça distanta : %s",
    "Request ID: %s" : "ID requèsta : %s",
    "Type: %s" : "Tipe : %s",
    "Code: %s" : "Còdi : %s",
    "Message: %s" : "Messatge : %s",
    "File: %s" : "Fichièr : %s",
    "Line: %s" : "Linha : %s",
    "Trace" : "Traça",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Sembla que sètz a reïnstallar vòstre Nextcloud. Pasmens lo fichièr CAN_INSTALL es absent del repertòri config. Volgatz ben crear lo fichièr CAN_INSTALL dins vòstre dossièr config per contunhar.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Supression impossibla de CAN_INSTALL dins lo repertòri config. Mercés de lo tirar manualament.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aquesta aplicacion requerís JavaScript per foncionar coma cal. {linkstart}Activatz JavaScript{linkend} e recargatz la pagina.",
    "Skip to main content" : "Sautar al contengut principal",
    "Skip to navigation of app" : "Passar a la navegacion d’aplications",
    "Go to %s" : "Anar a %s",
    "Get your own free account" : "Obtenètz vòstre pròpri compte gratuit",
    "Connect to your account" : "Connectatz-vos a vòstre compte",
    "Please log in before granting %1$s access to your %2$s account." : "Autentificatz-vos abans de donnar l’accès a %1$s a vòstre compte %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se ensajatz pas de configurar un periferic novèl o una aplicacion novèla, qualqu’un ensaja de vos far donar accès a vòstras donadas. En aqueste cas, contunhetz pas e contactatz vòstre administrator sistèma.",
    "Grant access" : "Donar accès",
    "Alternative log in using app password" : "Connexion alternativa en utilizant un senhal d’aplicacion",
    "Account access" : "Accès compte",
    "Currently logged in as %1$s (%2$s)." : "Actualament connectat coma %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Sètz a mand de donar accès a vòstra compte %2$s a %1$s.",
    "Account connected" : "Compte connectat",
    "Your client should now be connected!" : "Vòstre client deu èsser connectat ara !",
    "You can close this window." : "Podètz tampar aquesta fenèstra.",
    "Previous" : "Precedent",
    "This share is password-protected" : "Aqueste partiment es protegit per un senhal",
    "Email address" : "Adreça mail",
    "Password sent!" : "Senhal enviat !",
    "You are not authorized to request a password for this share" : "Sètz pas autorizat a demandar un senhal per aqueste partiment",
    "Two-factor authentication" : "Autentificacion dos factors",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "La seguretat renfortida es activada per vòstre compte. Causissètz un segond factor per l’autentificacion :",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Cargament impossible d’almens un metòde d’autentificacion dos factors. Contactatz vòstre admin.",
    "Set up two-factor authentication" : "Configurar l’autentificacion dos factors",
    "Use backup code" : "Utilizar còde de recuperacion",
    "Cancel login" : "Anullar connexion",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "La seguretat renfortida es aplicada a vòstre compte. Causissètz un provesidor de configurar :",
    "Error while validating your second factor" : "Error pendent la validacion del segond factor",
    "Access through untrusted domain" : "Accès via un domeni pas fisable",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Contactatz vòstre administrator. Se ne sètz un, modificatz lo paramètre « trusted_domains » dins config/config.php coma l’exemple dins config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Per mai d’informacions per configurar aquò consultatz la %1$sdocumentacion%2$s.",
    "App update required" : "Mesa a jorn d’aplicacion requerida",
    "%1$s will be updated to version %2$s" : "%1$s serà passat a la version %2$s",
    "The following apps will be updated:" : "Las aplicacions seguentas seràn mesas a jorn :",
    "These incompatible apps will be disabled:" : "Aquestas aplicacions incompatiblas seràn desactivadas :",
    "The theme %s has been disabled." : "Lo tèma %s es estat desactivat.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asseguratz-vos que la basa de donadas, lo dossièr config e lo dossièr de donadas « data » foguèron salvagardats abans de contunhar.",
    "Start update" : "Començar la mesa a jorn",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Per evitar qu’expire lo temps d’espèra amb de bravas installacions, podètz a la plaça executar la comanda seguentas a partir del repertòri d’installacion :",
    "Detailed logs" : "Jornals detalhats",
    "Update needed" : "Mesa a jorn requerida",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Per d’ajuda, vejatz la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentacion</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sabi que se contunhi la mesa a jorn via l’interfàcia web i a un risc, que la requèsta s’execute e despasse lo delai e poiriá causar una pèrda de donadas, mas ai una salvagarda de seguretat e sabi cossí restaurar mon instància en cas de fracàs.",
    "Upgrade via web on my own risk" : "Accèpti lo risc de metre a nivèl",
    "Maintenance mode" : "Mòde manteniment",
    "This %s instance is currently in maintenance mode, which may take a while." : "L’instància %s es actualament en mòde manteniment, pòt trigar.",
    "This page will refresh itself when the instance is available again." : "Aquesta pagina s’actualizarà soleta quand l’instància serà disponibla de nòu.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contactatz l’administrator sistèma s’aqueste messatge ten d’aparéisser o apareis sens rason.",
    "Currently open" : "Actualament dobèrta",
    "Login with username or email" : "Connexion amb nom d’utilizaire o email",
    "Login with username" : "Connexion amb nom d’utilizaire",
    "Edit Profile" : "Modificar perfil",
    "Error loading message template: {error}" : "Error de cargament del modèl de messatge : {error}",
    "Very weak password" : "Senhal plan feble",
    "Weak password" : "Senhal feble",
    "So-so password" : "Senhal mejan",
    "Good password" : "Bon senhal",
    "Strong password" : "Senhal fòrt",
    "Profile not found" : "Perfil pas trobat",
    "The profile does not exist." : "Lo perfil existís pas.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vòstre repertòri de donadas e vòstres fichièrs son probablament accessibles a partir d’internet pr’amor que lo fichièr .htaccess fonciona pas.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per d’informacions per corrèctament configurar vòstre servidor, consultatz la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentacion</a>.",
    "Show password" : "Mostrar lo senhal",
    "Toggle password visibility" : "Alternar la visibilitat del senhal",
    "Configure the database" : "Configurar la basa de donadas",
    "Only %s is available." : "Sonque %s es disponible."
},
"nplurals=2; plural=(n > 1);");
